@@ -1,6 +1,5 @@
-from django.core.urlresolvers import RegexURLPattern, get_resolver, Resolver404, RegexURLResolver, resolve
+from django.core.urlresolvers import get_resolver, Resolver404
 from django.conf import settings
-from urlbreadcrumbs.url_hacks import BreadRegexURLResolver
 from urlbreadcrumbs.conf import NAME_MAPPING, PATH_SPLIT_CHAR, RESOLVER
 from django.utils.importlib import import_module
 
@@ -14,22 +13,25 @@ else:
 
 RESOLVER_INSTANCE = resolver
 
+
 def build_breadcrumbs(request):
     if RESOLVER_INSTANCE is None:
         import warnings
-        warnings.warn("You should provide a URLBREADCRUMBS_RESOLVER in your settings (eg. 'urlbreadcrumbs.BreadRegexURLResolver') "
-                "in order to correctly use the url function provided by django-url-breadcrumbs")
+        warnings.warn("You should provide a URLBREADCRUMBS_RESOLVER in your settings "
+                      "(eg. 'urlbreadcrumbs.BreadRegexURLResolver') "
+                      "in order to correctly use the url function provided by django-url-breadcrumbs")
 
     if RESOLVER_INSTANCE is not None:
         resolver = RESOLVER_INSTANCE
     else:
         resolver = get_resolver(settings.ROOT_URLCONF)
 
-    ret_list = [] # list of pairs (name, path)
+    ret_list = []  # list of pairs (name, path)
 
     path = request.path_info
     parts = path.split(PATH_SPLIT_CHAR)
-    if not parts[-1]: parts = parts[:-1] # loose last empty element
+    if not parts[-1]:
+        parts = parts[:-1]  # loose last empty element
     try_path = ""
     for part in parts:
         try_path = try_path + part + PATH_SPLIT_CHAR
@@ -47,7 +49,8 @@ def build_breadcrumbs(request):
                 from_mapping = NAME_MAPPING.get(lookup, False)
                 if from_mapping:
                     name = from_mapping
-                elif hasattr(resolver_match, 'breadcrumb_verbose_name') and resolver_match.breadcrumb_verbose_name is not None:
+                elif hasattr(resolver_match, 'breadcrumb_verbose_name') and \
+                        resolver_match.breadcrumb_verbose_name is not None:
                     name = resolver_match.breadcrumb_verbose_name
                 else:
                     name = resolver_match.url_name
@@ -57,5 +60,4 @@ def build_breadcrumbs(request):
         except Resolver404:
             pass
 
-    return { 'breadcrumbs' : ret_list }
-
+    return {'breadcrumbs': ret_list}
